Struct HeliusClient

pub struct HeliusClient {
    pub rpc_client: RpcClient,
    pub http_client: Client,
    pub cluster: ClusterType,
    /* private fields */
}

Fields

rpc_client: RpcClienthttp_client: Clientcluster: ClusterType

Implementations

Source

impl HeliusClient

pub fn new(api_key: String, cluster_type: ClusterType) -> Self

pub fn new_with_commitment( api_key: String, cluster_type: ClusterType, commitment_config: CommitmentConfig, ) -> Self

pub fn new_with_timeout( api_key: String, cluster_type: ClusterType, timeout: Duration, ) -> Self

pub fn new_with_timeout_and_commitment( api_key: String, cluster_type: ClusterType, timeout: Duration, commitment_config: CommitmentConfig, ) -> Self

pub fn new_with_timeouts_and_commitment( api_key: String, cluster_type: ClusterType, timeout: Duration, commitment_config: CommitmentConfig, confirm_transaction_initial_timeout: Duration, ) -> Self

pub fn new_mock(api_key: String, cluster_type: ClusterType) -> Self

pub fn new_mock_with_mocks( api_key: String, cluster_type: ClusterType, mocks: Mocks, ) -> Self

Source

impl HeliusClient

pub async fn get_naming_service_names( &self, address: String, ) -> ClientResult<Vec<String>>

Returns the Solana Naming Service name for a given address. GET request to https://api.helius.xyz/v0/addresses/{address}/names.

  • address - The address that you want names for.
Source

impl HeliusClient

pub async fn get_token_balances( &self, address: String, ) -> ClientResult<TokenBalancesResponse>

Returns the native balance and token balances for a given address. GET request to https://api.helius.xyz/v0/addresses/{address}/balances.

  • address - The address that you want token balances for.
pub async fn get_nfts( &self, address: String, page_number: Option<usize>, ) -> ClientResult<NftResponse>

Returns the NFTs held for a given address. GET request to https://api.helius.xyz/v0/addresses/{address}/nfts.

  • address - The address that you want nfts for.
pub async fn get_nfts_metadata( &self, token_mints: Vec<String>, ) -> ClientResult<Vec<NftMetadata>>

Returns NFT metadata for the given token mint addresses. POST request to https://api.helius.xyz/v1/nfts.

  • token_mints - The nft mint addresses that you want metadata for.
pub async fn get_nft_events_for_address( &self, config: RequestConfig, ) -> ClientResult<Vec<NftEvent>>

Returns all NFT related events associated with the given address. POST request to https://api.helius.xyz/v1/nft-events.

pub async fn get_nft_events( &self, config: RequestConfig, ) -> ClientResult<Vec<NftEvent>>

Returns all NFT related events associated with the given address. GET request to https://api.helius.xyz/v1/addresses/{address}/nft-events.

pub async fn get_active_nft_listings( &self, config: ActiveListingsRequestConfig, ) -> ClientResult<ActiveListingsResponse>

Query for active NFT listings. POST request to https://api.helius.xyz/v1/active-listings.

pub async fn get_mint_list( &self, config: MintListRequestConfig, ) -> ClientResult<MintListResponse>

Returns a list of mint accounts for a given NFT collection. POST request to https://api.helius.xyz/v1/mintlist.

pub async fn get_tokens_metadata( &self, token_mints: Vec<String>, ) -> ClientResult<Vec<TokenMetadata>>

Returns token metadata (whether NFT or Fungible) for the given token mint addresses. POST request to https://api.helius.xyz/v0/tokens/metadata.

  • token_mints - The token mint addresses that you want metadata for.
Source

impl HeliusClient

pub async fn get_transactions_for_address( &self, config: GetRawTransactionsRequestConfig, ) -> ClientResult<Vec<RawTransaction>>

Returns raw transaction history for a given address. GET request to https://api.helius.xyz/v0/addresses/{address}/raw-transactions.

pub async fn get_transactions_by_hash( &self, transaction_hashes: Vec<String>, commitment: Option<CommitmentLevel>, ) -> ClientResult<Vec<RawTransaction>>

Returns raw transaction information for the given transaction hashes. POST request to https://api.helius.xyz/v0/raw-transactions.

  • transaction_hashes - The transaction hashes as Strings.
  • commitment - an Option containing the CommitmentLevel. Default is finalized.
pub async fn get_enriched_transactions( &self, config: RequestConfig, ) -> ClientResult<Vec<EnrichedTransaction>>

Returns enriched transaction history for a given address. GET request to https://api.helius.xyz/v0/addresses/{address}/transactions.

  • address - The address that you want transactions for.
pub async fn get_enriched_transactions_by_hash( &self, transaction_hashes: Vec<String>, commitment: Option<CommitmentLevel>, ) -> ClientResult<Vec<EnrichedTransaction>>

Returns enriched transaction information for the given transaction hashes. POST request to https://api.helius.xyz/v0/transactions.

  • transaction_hashes - The transaction hashes as Strings.
  • commitment - an Option containing the CommitmentLevel. Default is finalized.
Source

impl HeliusClient

pub async fn create_webhook( &self, webhook_request: CreateWebhookRequest, ) -> ClientResult<Webhook>

Creates a webhook. POST request to https://api.helius.xyz/v0/webhooks.

pub async fn get_webhooks(&self) -> ClientResult<Vec<Webhook>>

Returns all webhooks for the API key used to create the HeliusClient. GET request to https://api.helius.xyz/v0/webhooks.

pub async fn get_webhook(&self, webhook_id: String) -> ClientResult<Webhook>

Returns a single webhook. GET request to https://api.helius.xyz/v0/webhooks/{webhook_id}.

  • webhook_id - The webhook that you want to fetch.
pub async fn edit_webhook( &self, webhook_id: String, new_webhook: CreateWebhookRequest, ) -> ClientResult<Webhook>

Edits a webhook. PUT request to https://api.helius.xyz/v0/webhooks/{webhook_id}.

  • webhook_id - The webhook that you want to edit.
pub async fn delete_webhook(&self, webhook_id: String) -> ClientResult<()>

Deletes a webhook. DELETE request to https://api.helius.xyz/v0/webhooks/{webhook_id}.

  • webhook_id - The webhook that you want to delete.